@@ -1105,7 +1105,7 @@ class Config(models.Model):
     """
     id = models.CharField(max_length=255, primary_key=True, db_column="config_name",
         # varchar(255)
-        help_text="primary key"
+        help_text="config name, primary key"
     )
     config_value = models.CharField(max_length=255,
         # varchar(255)
@@ -1117,7 +1117,7 @@ class Config(models.Model):
         help_text="Is dynamic?"
     )
     def __unicode__(self):
-            return u"%s: %s" % (self.config_name, self.config_value)
+            return u"%s: %s" % (self.id, self.config_value)
     class Meta:
         db_table = u"%sconfig" % settings.PHPBB_TABLE_PREFIX
 
@@ -1202,42 +1202,6 @@ class AclRoleData(models.Model):
     class Meta:
         db_table = u"%sacl_roles_data" % settings.PHPBB_TABLE_PREFIX
 
-class AclUser(models.Model):
-    """
-    Permission roles and/or individual permissions assigned to users
-    """
-    # user_id = models.IntegerField()
-    user = models.ForeignKey("User", blank=True,
-        # mediumint(8) unsigned
-        default=0,
-        help_text="{{fk|users|user_id}}"
-    )
-    # forum_id = models.IntegerField()
-    forum = models.ForeignKey("Forum", blank=True,
-        # mediumint(8) unsigned
-        default=0,
-        help_text="{{fk|forums|forum_id}}"
-    )
-    # auth_option_id = models.IntegerField()
-    auth_option = models.ForeignKey("AclOption", blank=True,
-        # mediumint(8) unsigned
-        default=0,
-        help_text="{{fk|acl_options|auth_option_id}}"
-    )
-    # auth_role_id = models.IntegerField()
-    auth_role = models.ForeignKey("AclRole", blank=True,
-        # mediumint(8) unsigned
-        default=0,
-        help_text="{{fk|acl_roles|role_id}}"
-    )
-    auth_setting = models.IntegerField(
-        # tinyint(2)
-        default=0,
-        help_text="ACL_YES, ACL_NO or ACL_NEVER "
-    )
-    class Meta:
-        db_table = u"%sacl_users" % settings.PHPBB_TABLE_PREFIX
-
 
 class Banlist(models.Model):
     """
@@ -1278,6 +1242,7 @@ class Banlist(models.Model):
     class Meta:
         db_table = u"%sbanlist" % settings.PHPBB_TABLE_PREFIX
 
+
 class Bbcode(models.Model):
     """
     Custom BBCodes
@@ -1363,12 +1328,6 @@ class Bot(models.Model):
     class Meta:
         db_table = u"%sbots" % settings.PHPBB_TABLE_PREFIX
 
-class CaptchaAnswers(models.Model):
-    question_id = models.IntegerField()
-    answer_text = models.CharField(max_length=255)
-    class Meta:
-        db_table = u"%scaptcha_answers" % settings.PHPBB_TABLE_PREFIX
-
 class CaptchaQuestions(models.Model):
     id = models.IntegerField(primary_key=True, db_column="question_id")
     strict = models.IntegerField()
@@ -1381,11 +1340,9 @@ class CaptchaQuestions(models.Model):
 class Confirm(models.Model):
     """
     Contains session information for confirm pages ("are you sure you want to delete foo")
+    
+    Note: Not really supported mode, because no field is really unique!!!
     """
-    id = models.CharField(max_length=96, primary_key=True, db_column="confirm_id",
-        # char(32)
-        help_text="primary key"
-    )
     id = models.CharField(max_length=96, primary_key=True, db_column="session_id",
         # char(32)
         help_text="primary key, The session ID associated with the registration attempt."
@@ -1423,6 +1380,8 @@ class Disallow(models.Model):
     disallow_username = models.CharField(max_length=255,
         # varchar(255)
     )
+    def __unicode__(self):
+        return self.disallow_username
     class Meta:
         db_table = u"%sdisallow" % settings.PHPBB_TABLE_PREFIX
 
@@ -1517,29 +1476,6 @@ class Extension(models.Model):
     class Meta:
         db_table = u"%sextensions" % settings.PHPBB_TABLE_PREFIX
 
-
-class ForumTrack(models.Model):
-    """
-    Unread post information is stored here
-    """
-    id = models.PositiveIntegerField(primary_key=True, db_column="user_id",
-        # mediumint(8) unsigned
-        default=0,
-        help_text="primary key"
-    )
-    id = models.PositiveIntegerField(primary_key=True, db_column="forum_id",
-        # mediumint(8) unsigned
-        default=0,
-        help_text="primary key"
-    )
-    mark_time = models.PositiveIntegerField(
-        # int(11) unsigned
-        default=0,
-    )
-    class Meta:
-        db_table = u"%sforums_track" % settings.PHPBB_TABLE_PREFIX
-
-
 class Icon(models.Model):
     """
     Post icons
@@ -1642,20 +1578,6 @@ class Log(models.Model):
     class Meta:
         db_table = u"%slog" % settings.PHPBB_TABLE_PREFIX
 
-class LoginAttempt(models.Model):
-    """
-    tbd
-    """
-    attempt_ip = models.CharField(max_length=40)
-    attempt_browser = models.CharField(max_length=150)
-    attempt_forwarded_for = models.CharField(max_length=255)
-    attempt_time = models.IntegerField()
-    user_id = models.IntegerField()
-    username = models.CharField(max_length=255)
-    username_clean = models.CharField(max_length=255)
-    class Meta:
-        db_table = u"%slogin_attempts" % settings.PHPBB_TABLE_PREFIX
-
 
 class Module(models.Model):
     """
@@ -1703,27 +1625,6 @@ class Module(models.Model):
     class Meta:
         db_table = u"%smodules" % settings.PHPBB_TABLE_PREFIX
 
-class PollOption(models.Model):
-    """
-    Options text of all votes ("Yes", "No", "Maybe"...)
-    """
-    poll_option_id = models.IntegerField(
-        # tinyint(4)
-        default=0,
-    )
-    topic = models.ForeignKey("Topic", blank=True,
-        # mediumint(8) unsigned
-        default=0,
-    )
-    poll_option_text = models.TextField(
-        # text
-    )
-    poll_option_total = models.PositiveIntegerField(
-        # mediumint(8) unsigned
-        default=0,
-    )
-    class Meta:
-        db_table = u"%spoll_options" % settings.PHPBB_TABLE_PREFIX
 
 class Privmsg(models.Model):
     """
@@ -2025,16 +1926,6 @@ class ProfileLang(models.Model):
     class Meta:
         db_table = u"%sprofile_lang" % settings.PHPBB_TABLE_PREFIX
 
-class QaConfirm(models.Model):
-    session_id = models.CharField(max_length=96)
-    confirm_id = models.CharField(max_length=96)
-    lang_iso = models.CharField(max_length=30)
-    question_id = models.IntegerField()
-    attempts = models.IntegerField()
-    confirm_type = models.IntegerField()
-    class Meta:
-        db_table = u"%sqa_confirm" % settings.PHPBB_TABLE_PREFIX
-
 class Rank(models.Model):
     """
     Rank (Name, image, minimal # of posts)
@@ -2165,24 +2056,6 @@ class SearchWordlist(models.Model):
     class Meta:
         db_table = u"%ssearch_wordlist" % settings.PHPBB_TABLE_PREFIX
 
-class SearchWordmatch(models.Model):
-    """
-    Associate a post with indexed words
-    """
-    post_id = models.PositiveIntegerField(
-        # mediumint(8) unsigned
-        default=0,
-    )
-    word_id = models.PositiveIntegerField(
-        # mediumint(8) unsigned
-        default=0,
-    )
-    title_match = models.PositiveSmallIntegerField(unique=True,
-        # tinyint(1) unsigned
-        default=0,
-    )
-    class Meta:
-        db_table = u"%ssearch_wordmatch" % settings.PHPBB_TABLE_PREFIX
 
 class Session(models.Model):
     """
@@ -2392,9 +2265,9 @@ class StyleTemplate(models.Model):
 
 class StyleTemplateData(models.Model):
     """
-    tbd
+    FIXME: template_id is a ForeignKey to StyleTemplate?
     """
-    template_id = models.IntegerField(
+    template = models.IntegerField(primary_key=True, db_column="template_id",
         # tinyint(4)
     )
     template_filename = models.CharField(max_length=100,
@@ -2444,29 +2317,6 @@ class StyleTheme(models.Model):
     class Meta:
         db_table = u"%sstyles_theme" % settings.PHPBB_TABLE_PREFIX
 
-
-
-class TopicPosted(models.Model):
-    """
-    Who posted to which topic (used for the small dots in viewforum)
-    """
-    id = models.PositiveIntegerField(primary_key=True, db_column="user_id",
-        # mediumint(8) unsigned
-        default=0,
-        help_text="primary key"
-    )
-    id = models.PositiveIntegerField(primary_key=True, db_column="topic_id",
-        # mediumint(8) unsigned
-        default=0,
-        help_text="primary key"
-    )
-    topic_posted = models.PositiveSmallIntegerField(
-        # tinyint(1) unsigned
-        default=0,
-    )
-    class Meta:
-        db_table = u"%stopics_posted" % settings.PHPBB_TABLE_PREFIX
-
 class TopicTrack(models.Model):
     """
     Unread post information is stored here
